<template>
  <div class="service-contract">
    <SearchCommonView ref="searchCommonView" :query-class-options="queryClassOptions" :search-options="searchOptions" />
    <div class="btn-pager">
      <PublicFunctionBtnView :submit-approval="true" :operates-list="operatesList" />
      <PagerView class="page" />
    </div>
    <TableCommonView ref="tableListRef" :table-list="tableList">
      <template slot="tableButton">
        <el-table-column label="操作" width="60">
          <template slot-scope="scope">
            <el-button @click="handleClick(scope.row)" type="text" size="small">编辑</el-button>
          </template>
        </el-table-column>
      </template>
    </TableCommonView>
    <!-- 新建/编辑 -->
    <AddServiceContractDialog v-if="editConfig.visible" :edit-common-config="editConfig" />
  </div>
</template>

<script>
import SearchCommonView from "@/components/makepager/SearchCommonView"
import PublicFunctionBtnView from "@/components/makepager/PublicFunctionBtnView"
import PagerView from "@/components/makepager/PagerView"
import TableCommonView from "@/components/makepager/TableCommonView"
import AddServiceContractDialog from "@/views/service/serviceContract/AddServiceContractDialog"

export default {
  name: "ServiceContract",
  props: {},
  components: {
    SearchCommonView,
    PublicFunctionBtnView,
    PagerView,
    TableCommonView,
    AddServiceContractDialog
  },
  computed: {
    searchCommonHeight() {
      return this.$refs.searchCommonView.offsetHeight
    }
  },
  data() {
    return {
      tableList: {},
      queryClassOptions: [
        { value: "1", label: "全部" },
        { value: "2", label: "30天后过期" },
        { value: "3", label: "60天后过期" },
        { value: "4", label: "已过期15天" },
        { value: "5", label: "已过期60天" }
      ],
      searchOptions: [],
      operatesList: [
        { id: "1", name: "共享" },
        { id: "2", name: "批量编辑" },
        { id: "3", name: "导出" },
        { id: "4", name: "下载全部附件" },
        { id: "5", name: "更改创建人" },
        { id: "6", name: "电子签署管理后台" },
        { id: "7", name: "树结构设置" },
        { id: "8", name: "审批设置" },
        { id: "9", name: "恢复预设列宽" }
      ],
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      }
    }
  },
  created() {
    this.setTable()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [
          {
            serviceContractNumber: "FWHT20230703123",
            customName: "上海铃铛信息科技有限公司",
            signDate: "2023-06-26",
            contractType: "按年",
            contractStatus: "已创建",
            owner: "Boss",
            productName: "软件",
            startDate: "2023-06-26",
            endDate: "2024-06-25",
            priceTax: "¥5,000.00"
          }
        ],
        tableColumn: [
          { label: "服务合同编号", prop: "serviceContractNumber", min: 100 }, // 服务合同编号
          { label: "客户名称", prop: "customName", min: 120 }, // 客户名称
          { label: "签约日期", prop: "signDate" }, // 签约日期
          { label: "合同类型", prop: "contractType" }, // 合同类型
          { label: "合同状态", prop: "contractStatus" }, // 合同状态
          { label: "负责人", prop: "owner" }, // 负责人
          { label: "产品名称", prop: "productName" }, // 产品名称
          { label: "服务开始日", prop: "startDate" }, // 服务开始日
          { label: "服务到期日", prop: "endDate" }, // 服务到期日
          { label: "价税合计", prop: "priceTax" } // 价税合计
        ]
      }
      this.searchOptions = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        const label = this.tableList.tableColumn[i].label
        this.searchOptions.push({ value: (i + 1).toString(), label: label })
      }
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      this.editConfig.infomation = {
        customName: "",
        serviceContractNumber: "AC6521",
        owner: "5",
        contactName: "",
        salesOpportunity: "",
        contractOrder: "",
        quotation: "",
        contractType: "",
        signDate: "",
        startDate: "",
        endDate: "",
        contractStatus: "",
        serviceNumber: "",
        termsTreaty: "",
        notes: "",
        approvalWorkflow: "",
        approvalSteps: "",
        approvalPerson: "",
        approvalOpinion: ""
      }
    },
    // 编辑
    handleClick(row) {
      console.log(row)
      this.editSalesLeadConfig.visible = true
      this.editSalesLeadConfig.title = "编辑"
      this.editSalesLeadConfig.infomation = {
        customName: "",
        serviceContractNumber: "AC6521",
        owner: "5",
        contactName: "",
        salesOpportunity: "",
        contractOrder: "",
        quotation: "",
        contractType: "",
        signDate: "",
        startDate: "",
        endDate: "",
        contractStatus: "",
        serviceNumber: "",
        termsTreaty: "",
        notes: "",
        approvalWorkflow: "",
        approvalSteps: "",
        approvalPerson: "",
        approvalOpinion: ""
      }
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.service-contract {
  .btn-pager {
    display: flex;
    .page {
      margin-left: auto;
    }
  }
}
</style>
